package com.fastbee.ggroup.service;

import java.util.List;
import com.fastbee.ggroup.domain.GSites;
import com.fastbee.ggroup.domain.dto.GGroupSiteDto;
import com.fastbee.ggroup.domain.dto.GGroupSiteRelateDto;
import com.fastbee.ggroup.domain.dto.GSitesEditDto;
import com.fastbee.ggroup.domain.dto.GSitesSelectDto;

/**
 * 站点Service接口
 * 
 * @author kerwincui
 * &#064;date  2024-09-29
 */
public interface IGSitesService 
{
    /**
     * 查询站点
     */
    GSites selectGSitesById(Long id);

    /**
     * 查询站点列表
     */
    List<GSites> selectGSitesList(GSitesSelectDto gSites);

    /**
     * 新增站点
     */
    int insertGSites(GGroupSiteDto gGroupSiteDto);

    /**
     * 修改站点
     */
    int updateGSites(GSitesEditDto gSitesEditDto);

    /**
     * 批量删除站点
     */
    int deleteGSitesByIds(Long[] ids);

    /**
     * 删除站点信息
     */
    int deleteGSitesById(Long id);

    /**
     * 站点关联组
     */
    int relateGroup(GGroupSiteRelateDto gGroupSiteRelateDto);

    /**
     * 搜索站点列表
     */
    List<GSites> searchGSitesList(GSites gSites);
}
